@@ -683,7 +683,7 @@ class TestClientCSVParameterSupport:
         
         # Verify methods were called correctly
         mock_get_data.assert_called_once_with(
-            [2], "2023-01-01", "2023-01-02", [], 'E', True
+            [2], "2023-01-01", "2023-01-02", [], 'M', True
         )
         mock_export.assert_called_once_with(mock_weather_data, None)
     
@@ -764,7 +764,7 @@ class TestClientCSVParameterSupport:
         
         # Verify methods were called correctly (prioritize_scs=False for hourly)
         mock_get_data.assert_called_once_with(
-            [2], "2023-01-01", "2023-01-01", [], 'E', prioritize_scs=False
+            [2], "2023-01-01", "2023-01-01", [], 'M', prioritize_scs=False
         )
         mock_export.assert_called_once_with(mock_weather_data, None, separate_daily_hourly=False)
     
